# Generated by roxygen2: do not edit by hand

export(create_monolayer_network)
export(create_multilayer_network)
export(get_igraph)
export(get_sam)
export(list_to_matrix)
export(load_emln)
export(matrix_to_list_bipartite)
export(matrix_to_list_unipartite)
export(multilayer_to_csv)
export(multilayer_to_json)
export(plot_multilayer)
export(search_emln)
export(view_emln)
import(DT)
import(dplyr)
import(tibble)
import(tidyr)
importFrom(Matrix,Matrix)
importFrom(hablar,retype)
importFrom(igraph,V)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,as_biadjacency_matrix)
importFrom(igraph,degree)
importFrom(igraph,delete_vertex_attr)
importFrom(igraph,graph.incidence)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_biadjacency_matrix)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,is_directed)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(purrr,compact)
importFrom(rlang,.data)
importFrom(stringr,str_detect)
importFrom(stringr,str_to_title)
