#'
#' @docType data
#' @title emln78_temporal_zackenberg_2013
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     78     |        Temporal         |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source plos
#' @source https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0081694
#' @md
#' @keywords internal
'emln78_temporal_zackenberg_2013'
