#'
#' @docType data
#' @title emln71_temporal_perturbation_kaiser_bunbury_2009
#' 
#' @description Network Description:
#' 
#' | network_id |  multilayer_network_type   | ecological_network_type | state_nodes |
#' |:----------:|:--------------------------:|:-----------------------:|:-----------:|
#' |     71     | Temporal    , Perturbation |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Interaction_Web_DataBase
#' @source Web_of_Life
#' @source http://www.ecologia.ib.usp.br/iwdb/html/kaiser-bunbury_2009.html
#' @source http://www.web-of-life.es/map.php
#' @md
#' @keywords internal
'emln71_temporal_perturbation_kaiser_bunbury_2009'
