#'
#' @docType data
#' @title emln64_temporal_caradona_2020
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     64     |        Temporal         |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source EDI_data_portal
#' @source https://portal.edirepository.org/nis/mapbrowse?packageid=edi.512.1
#' @md
#' @keywords internal
'emln64_temporal_caradona_2020'
