#'
#' @docType data
#' @title emln14_multiplex_mello_2019
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     14     |        Multiplex        |     Seed-Dispersal      |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source http://www.web-of-life.es
#' @md
#' @keywords internal
'emln14_multiplex_mello_2019'
