#'
#' @docType data
#' @title emln17_multiplex_traveset_2020
#'
#' @description Network Description:
#'
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     17     |        Multiplex        |        Multiple         |    FALSE    |
#'
#' @format NULL
#' @usage NULL
#' @source Figshare
#' @source https://doi.org/10.6084/m9.figshare.c.5208546.v1
#' @md
#' @keywords internal
'emln17_multiplex_traveset_2020'
