#'
#' @docType data
#' @title emln43_spatial_montero_2005
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     43     |         Spatial         |       Pollination       |    TRUE     |
#' 
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source http://www.web-of-life.es/map.php
#' @md
#' @keywords internal
'emln43_spatial_montero_2005'
