#'
#' @docType data
#' @title emln54_spatial_snow b_k_&snow_1988
#'
#' @description Network Description:
#'
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     54     |         Spatial         |       Pollination       |    TRUE     |
#'
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source Interaction_Web_DataBase
#' @source http://www.ecologia.ib.usp.br/iwdb/html/snow_snow_1971.htm
#' @source http://www.web-of-life.es/map.php?type=6
#' @md
#' @keywords internal
'emln54_spatial_snow_b_k_snow_1988'
