#'
#' @docType data
#' @title emln48_environment_perturbation_bartomeus_2008
#' 
#' @description Network Description:
#' 
#' | network_id |  multilayer_network_type   | ecological_network_type | state_nodes |
#' |:----------:|:--------------------------:|:-----------------------:|:-----------:|
#' |     48     | Environment , Perturbation |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source Interaction_Web_DataBase
#' @source http://www.ecologia.ib.usp.br/iwdb/html/bartomeus_2008.html
#' @source http://www.web-of-life.es/map.php
#' @md
#' @keywords internal
'emln48_environment_perturbation_bartomeus_2008'
