#'
#' @docType data
#' @title emln69_temporal_fang_2012
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     69     |        Temporal         |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source web
#' @source https://figshare.com/articles/dataset/Relative_Stability_of_Core_Groups_in_Pollination_Networks_in_a_Biodiversity_Hotspot_over_Four_Years/127797
#' @md
#' @keywords internal
'emln69_temporal_fang_2012'
