#'
#' @docType data
#' @title emln25_spatial_carstensen_2014
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     25     |         Spatial         |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source figshare
#' @source https://figshare.com/articles/dataset/_Beta_Diversity_of_Plant_Pollinator_Networks_and_the_Spatial_Turnover_of_Pairwise_Interactions_/1234708
#' @md
#' @keywords internal
'emln25_spatial_carstensen_2014'
