#'
#' @docType data
#' @title emln73_temporal_ramos_robles_2016
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     73     |        Temporal         |     Seed-Dispersal      |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source PeerJ
#' @source https://peerj.com/articles/2048/#supplemental-information
#' @md
#' @keywords internal
'emln73_temporal_ramos_robles_2016'
