#'
#' @docType data
#' @title emln16_multiplex_pocock_2012
#'
#' @description Network Description:
#'
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     16     |        Multiplex        |        Multiple         |    FALSE    |
#'
#' @format NULL
#' @usage NULL
#' @source Dryad
#' @source https://datadryad.org/stash/dataset/doi:10.5061/dryad.3s36r118
#' @md
#' @keywords internal
'emln16_multiplex_pocock_2012'
