#'
#' @docType data
#' @title emln23_spatial_canadian_fish_parasite
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     23     |         Spatial         |      Host-Parasite      |    TRUE     |
#' 
#' @format NULL
#' @usage NULL
#' @source Interaction_Web_DataBase
#' @source http://www.ecologia.ib.usp.br/iwdb/html/canadian_fish.html
#' @md
#' @keywords internal
'emln23_spatial_canadian_fish_parasite'
