#'
#' @docType data
#' @title emln6_environment_kohler_2011
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     6      |       Environment       |       Pollination       |    TRUE     |
#' 
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source Interaction_Web_DataBase
#' @source http://www.web-of-life.es/map.php?type=6
#' @source http://www.ecologia.ib.usp.br/iwdb/html/schleuning-et-al-2010.html
#' @md
#' @keywords internal
'emln6_environment_kohler_2011'
