#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end

utils::globalVariables(c("descriptions",
                         "from", "to", "layer", "layer_id", "name"))

