#'
#' @docType data
#' @title emln49_spatial_perturbation_vazquez_2002
#' 
#' @description Network Description:
#' 
#' | network_id |  multilayer_network_type   | ecological_network_type | state_nodes |
#' |:----------:|:--------------------------:|:-----------------------:|:-----------:|
#' |     49     | Spatial     , Perturbation |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Interaction_Web_DataBase
#' @source http://www.ecologia.ib.usp.br/iwdb/html/vazquez_2002.html
#' @md
#' @keywords internal
'emln49_spatial_perturbation_vazquez_2002'
