#'
#' @docType data
#' @title emln13_multiplex_kefi_2016
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     13     |        Multiplex        |        Food-Web         |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Dryad
#' @source https://datadryad.org/stash/dataset/doi:10.5061/dryad.b4vg0
#' @md
#' @keywords internal
'emln13_multiplex_kefi_2016'
