#'
#' @docType data
#' @title emln65_temporal_chacoff_2020
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     65     |        Temporal         |       Pollination       |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Dryad
#' @source https://datadryad.org/stash/dataset/doi:10.5061/dryad.8cz8w9gm1
#' @md
#' @keywords internal
'emln65_temporal_chacoff_2020'
