#'
#' @docType data
#' @title emln41_spatial_melian_2015
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     41     |         Spatial         |        Food-Web         |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Dryad
#' @source https://datadryad.org/stash/dataset/doi:10.5061/dryad.06bb5
#' @md
#' @keywords internal
'emln41_spatial_melian_2015'
