#'
#' @docType data
#' @title emln1_environment_schleuning_2010
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     1      |       Environment       |     Seed-Dispersal      |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Interaction_Web_DataBase
#' @source http://www.ecologia.ib.usp.br/iwdb/html/schleuning-et-al-2010.html
#' @md
#' @keywords internal
'emln1_environment_schleuning_2010'
