#'
#' @docType data
#' @title emln46_spatial_p_jordano_unpubl
#' 
#' @description Network Description:
#' 
#' | network_id | multilayer_network_type | ecological_network_type | state_nodes |
#' |:----------:|:-----------------------:|:-----------------------:|:-----------:|
#' |     46     |         Spatial         |     Seed-Dispersal      |    FALSE    |
#' 
#' @format NULL
#' @usage NULL
#' @source Web_of_Life
#' @source http://www.web-of-life.es/map.php
#' @md
#' @keywords internal
'emln46_spatial_p_jordano_unpubl'
