% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/view_emln.R
\name{view_emln}
\alias{view_emln}
\title{View networks}
\usage{
view_emln()
}
\value{
An interactive GUI for browinsg through networks.
}
\description{
View the database interactively.
}
